@@ -50,7 +50,7 @@ def ClearRegistries():
 
 #Class definitions
 
-class House(registering.StoriedRegistry):
+class House(registering.StoriedRegistrar):
     """House Class for managing framework(s)
        includes store for framework and name registries for framers, frames, and actions
 
@@ -99,8 +99,6 @@ class House(registering.StoriedRegistry):
         self.slaves = [] #list of slave taskers in house
         self.moots = [] #list of moot framers in house
 
-        self.clones = [] # list of tuples of clone pair names (original, clone, human, count)
-
         self.resolvables = deque()  # deque of framers to be resolved
 
         self.names = odict() #houses dict of registry Names
@@ -144,6 +142,14 @@ class House(registering.StoriedRegistry):
             if not tasker.resolved and tasker not in self.moots:
                 self.resolvables.append(tasker)
 
+        self.resolveResolvables()
+
+    def resolveResolvables(self):
+        """
+        Continually resolve resolvables deque until empty.
+        Because a tasker (framer) may clone new framers
+        each resolve may add more resolvables
+        """
         while self.resolvables:
             tasker = self.resolvables.popleft()
             tasker.resolve()
